@@ -74,6 +74,8 @@ ImageTags = {
         ImageTags.preventRealLink(jQuery('.tag-link-plain'));
         // Hide save button and allow multi submit
         form.find('input.submit-widget').hide().addClass('allowMultiSubmit');
+        // Get decimal separator
+        ImageTags.separator = jQuery('#form-widgets-decimal').attr('value');
     },
     
     
@@ -170,20 +172,20 @@ ImageTags = {
         // Calculate real final position (0%<=position<=100%)
         var finalPosition = {};
         if(newX<0) {
-            newX = 0;
-            finalPosition['left'] = (newX - box.width()/2) + 'px';
+            newX = -box.width()/2;
+            finalPosition['left'] = newX + 'px';
         }
         if(newX>wWidth) {
-            newX = wWidth;
-            finalPosition['left'] = (newX - box.width()/2) + 'px';
+            newX = (wWidth - box.width()/2);
+            finalPosition['left'] = newX + 'px';
         }
         if(newY>wHeight) {
-            newY = wHeight;
-            finalPosition['top'] = (newY - box.height()/2) + 'px';
+            newY = (wHeight - box.height()/2);
+            finalPosition['top'] = newY + 'px';
         }
         if(newY<0) {
-            newY = 0;
-            finalPosition['top'] = (newY - box.height()/2)+ 'px';
+            newY = -box.height()/2;
+            finalPosition['top'] = newY + 'px';
         }
         // If "desired" position is out of limits, re-place the box
         if(finalPosition['top'] !== undefined || finalPosition['left'] !== undefined) {
@@ -327,6 +329,9 @@ ImageTags = {
         var prefix = 'form.widgets.';
         // Set default values in the form
         jQuery.each(config, function(field, value) {
+            if(field=='x' || field=='y') {
+                value = ImageTags.replaceDecimalSeparator(value);
+            }
             form.find('input[name=' + prefix + field + ']').val(value);
         });
     },
@@ -446,17 +451,6 @@ ImageTags = {
             plainTag.remove();
         });
         var plainTags = jQuery('.tag-plain-tags');
-        // Once removed, re-write tag-list with the corresponding hyphens.
-        
-/*        var children = plainTags.children().clone(true);
-        plainTags.empty();
-        children.each(function(pos, el) {
-            plainTags.append(el);
-            if(pos<children.length-1) {
-                plainTags.append(ImageTagsLabels.hyphenLabel);
-            }
-        });
-*/
         // If all labels were removed, show "No tags yet" legend.
         if(plainTags.children().length===0) {
             plainTags.hide().parent().find('.tag-plain-no-tag').show();
@@ -464,6 +458,17 @@ ImageTags = {
         }
     },
     
+    replaceDecimalSeparator: function(number) {
+        // Replace JavaScript number decimal separator with server expected decimal separator
+        var separator = ImageTags.separator;
+        if(separator!='.') {
+            return number.toString().replace('.', separator);
+        } else {
+            return number;
+        }
+
+    },
+    
     checkRequired: function(event) {
         /* Helper method to add/remove missing-value class to fields
          */
